pub struct AdobeRgb;Expand description
The Adobe RGB (1998) (a.k.a. opRGB) color space and standard.
This color space was designed to encompass most colors achievable by CMYK printers using RGB primaries. It has a wider color gamut than sRGB, primarily in cyan-green hues.
The Adobe RGB standard uses a gamma 2.2 transfer function.
As transfer function
AdobeRgb will not use any kind of approximation when converting from T to
T. This involves calls to powf, which may make it too slow for certain
applications.
There are some specialized cases where it has been optimized:
- When converting from
u8tof32orf64, while converting to linear space. This uses lookup tables with precomputed values. - When converting from
f32orf64tou8, while converting from linear space. This uses a fast algorithm that guarantees a maximum error in the result of less than 0.6 in line with this DirectX spec.
Implementations
Sourceimpl AdobeRgb
impl AdobeRgb
Sourcepub fn get_u8_to_f32_lut() -> IntoLinearLut<u8, f32, AdobeRgb, &'static ArrayTable<256>>
pub fn get_u8_to_f32_lut() -> IntoLinearLut<u8, f32, AdobeRgb, &'static ArrayTable<256>>
Access the pre-generated lookup table for non-linear u8 to linear f32 conversion.
Sourcepub fn get_u8_to_f64_lut() -> IntoLinearLut<u8, f64, AdobeRgb, &'static ArrayTable<256>>
pub fn get_u8_to_f64_lut() -> IntoLinearLut<u8, f64, AdobeRgb, &'static ArrayTable<256>>
Access the pre-generated lookup table for non-linear u8 to linear f64 conversion.
Sourcepub fn get_f32_to_u8_lut() -> FromLinearLut<f32, u8, AdobeRgb, &'static SliceTable>
pub fn get_f32_to_u8_lut() -> FromLinearLut<f32, u8, AdobeRgb, &'static SliceTable>
Access the pre-generated lookup table for linear f32 to non-linear u8 conversion.