pub struct IntoLinearLut<E, L, F, T>{ /* private fields */ }Expand description
Lookup table from gamma encoded to linear values.
E and L are the encoded and linear types, F is the transfer function,
and T determines the storage type for the table.
use palette::{Srgb, SrgbLuma, encoding, math::lut::VecTable};
// Accessing a pre-generated lookup table:
let lut = encoding::Srgb::get_u8_to_f32_lut();
let linear = lut.lookup_rgb(Srgb::new(23, 198, 76));
// Generating a new lookup table, allocated as a Vec:
let lut = encoding::IntoLinearLut::<_, f32, _, VecTable>::new_u8();
let linear = lut.lookup_rgb(Srgb::new(23, 198, 76));
// Looking up a Luma value:
let lut = encoding::Srgb::get_u8_to_f32_lut();
let linear = lut.lookup_luma(SrgbLuma::new(23));Implementations
Sourceimpl<L, F, T> IntoLinearLut<u8, L, F, T>
impl<L, F, T> IntoLinearLut<u8, L, F, T>
Sourcepub fn new_u8() -> IntoLinearLut<u8, L, F, T>
pub fn new_u8() -> IntoLinearLut<u8, L, F, T>
Generate a new lookup table that decodes from u8 values.
Sourceimpl<L, F, T> IntoLinearLut<u16, L, F, T>
impl<L, F, T> IntoLinearLut<u16, L, F, T>
Sourcepub fn new_u16() -> IntoLinearLut<u16, L, F, T>
pub fn new_u16() -> IntoLinearLut<u16, L, F, T>
Generate a new lookup table that decodes from u16 values.
Sourceimpl<E, L, F, T> IntoLinearLut<E, L, F, T>
impl<E, L, F, T> IntoLinearLut<E, L, F, T>
Sourcepub const fn from_table(table: Lut<E, L, T>) -> IntoLinearLut<E, L, F, T>
pub const fn from_table(table: Lut<E, L, T>) -> IntoLinearLut<E, L, F, T>
Create a lookup table from a component lookup table.
The input table will not be verified for correctness and may result in unintended values if it’s not for the intended transfer function. This function is primarily useful for code generation.
Sourcepub fn lookup_rgb<S>(&self, encoded: Rgb<S, E>) -> Rgb<Linear<S>, L>
pub fn lookup_rgb<S>(&self, encoded: Rgb<S, E>) -> Rgb<Linear<S>, L>
Get an RGB value from the table.
Sourcepub fn lookup_luma<S>(&self, encoded: Luma<S, E>) -> Luma<Linear<S>, L>
pub fn lookup_luma<S>(&self, encoded: Luma<S, E>) -> Luma<Linear<S>, L>
Get a luma value from the table.