pub struct P3Gamma;Expand description
A gamma 2.6 transfer function used by some P3 variants
P3Gamma will not use any kind of approximation when converting from T to
T. This involves calls to powf, which may make it too slow for certain
applications.
There are some specialized cases where it has been optimized:
- When converting from
u8tof32orf64, while converting to linear space. This uses lookup tables with precomputed values. - When converting from
f32orf64tou8, while converting from linear space. This uses a fast algorithm that guarantees a maximum error in the result of less than 0.6 in line with this DirectX spec.
Implementations
Sourceimpl P3Gamma
impl P3Gamma
Sourcepub fn get_u8_to_f32_lut() -> IntoLinearLut<u8, f32, P3Gamma, &'static ArrayTable<256>>
pub fn get_u8_to_f32_lut() -> IntoLinearLut<u8, f32, P3Gamma, &'static ArrayTable<256>>
Access the pre-generated lookup table for non-linear u8 to linear f32 conversion.
Sourcepub fn get_u8_to_f64_lut() -> IntoLinearLut<u8, f64, P3Gamma, &'static ArrayTable<256>>
pub fn get_u8_to_f64_lut() -> IntoLinearLut<u8, f64, P3Gamma, &'static ArrayTable<256>>
Access the pre-generated lookup table for non-linear u8 to linear f64 conversion.
Sourcepub fn get_f32_to_u8_lut() -> FromLinearLut<f32, u8, P3Gamma, &'static SliceTable>
pub fn get_f32_to_u8_lut() -> FromLinearLut<f32, u8, P3Gamma, &'static SliceTable>
Access the pre-generated lookup table for linear f32 to non-linear u8 conversion.