pub struct ProPhotoRgb;Expand description
The ProPhoto RGB standard and color space with gamma 2.2 transfer function.
About 13% of the colors in this space are “impossible colors” meaning that they model cone responses that are, in practice, impossible to achieve.
As transfer function
ProPhotoRgb will not use any kind of approximation when converting from T to
T. This involves a call to powf, which may make it too slow for certain
applications.
Using the gamma_lut_u16 feature allows certain specialized optimizations:
- When converting from
u16tof32orf64, while converting to linear space. This uses lookup tables with precomputed values. - When converting from
f32orf64tou16, while converting from linear space. This uses a fast algorithm that guarantees a maximum error in the result of less than 0.6 in line with this DirectX spec.