pub trait GetLutBuilder {
// Required method
fn get_lut_builder() -> GammaLutBuilder;
}Expand description
A transfer function that can produce a gamma lookup table.
See FromLinearLut and IntoLinearLut for how to use a type that
implements this trait to make a lookup table.
Required Methods
Sourcefn get_lut_builder() -> GammaLutBuilder
fn get_lut_builder() -> GammaLutBuilder
Get a builder for gamma lookup tables for this transfer function.
This function is called by FromLinearLut and IntoLinearLut to
generate their table entries.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.